@@ -41,13 +41,17 @@ class CalicoPlugin(Ml2Plugin, l3_db.L3_NAT_db_mixin):
     # Intercept floating IP associates/disassociates so we can trigger an
     # appropriate endpoint update.
     def _update_floatingip(self, context, id, floatingip):
+        LOG.info("CalicoPlugin _update_floatingip: %s", floatingip)
         old_floatingip, new_floatingip = super(
             CalicoPlugin, self)._update_floatingip(context, id, floatingip)
 
+        LOG.info("CalicoPlugin new_floatingip=%s", new_floatingip)
         if new_floatingip['port_id']:
             context.fip_update_port_id = new_floatingip['port_id']
             self.mechanism_manager._call_on_drivers('update_floatingip',
                                                     context)
+
+        LOG.info("CalicoPlugin old_floatingip=%s", old_floatingip)
         if old_floatingip['port_id']:
             context.fip_update_port_id = old_floatingip['port_id']
             self.mechanism_manager._call_on_drivers('update_floatingip',
@@ -57,11 +61,13 @@ class CalicoPlugin(Ml2Plugin, l3_db.L3_NAT_db_mixin):
 
     def create_floatingip(self, context, floatingip,
                           initial_status=constants.FLOATINGIP_STATUS_ACTIVE):
+        LOG.info("CalicoPlugin create_floatingip: %s", floatingip)
         new_floatingip = super(CalicoPlugin, self).create_floatingip(
             context,
             floatingip,
             initial_status=initial_status
         )
+        LOG.info("CalicoPlugin new_floatingip=%s", new_floatingip)
         if new_floatingip['port_id']:
             context.fip_update_port_id = new_floatingip['port_id']
             self.mechanism_manager._call_on_drivers('update_floatingip',
