@@ -31,7 +31,6 @@ from networking_calico.common import config as calico_config
 from networking_calico.compat import cfg
 from networking_calico.compat import DHCPV6_STATEFUL
 from networking_calico import datamodel_v1
-from networking_calico import datamodel_v3
 from networking_calico.etcdutils import EtcdWatcher
 
 LOG = logging.getLogger(__name__)
@@ -77,6 +76,7 @@ class TestDhcpAgent(base.BaseTestCase):
         self.mock_makedirs_p = mock.patch("os.makedirs")
         self.mock_makedirs = self.mock_makedirs_p.start()
         self.hostname = socket.gethostname()
+        cfg.CONF.host = self.hostname
 
     def test_mainline(self):
         # Create the DHCP agent.
@@ -311,7 +311,21 @@ class TestDhcpAgent(base.BaseTestCase):
     def test_etcd_watchers_init_with_conf_values(self):
         agent = CalicoDhcpAgent()
         self.assertEqual(agent.etcd.prefix,
-                         datamodel_v3._build_key("WorkloadEndpoint", ""))
+                         "/calico/resources/v3/projectcalico.org/" +
+                         "workloadendpoints/openstack/" +
+                         self.hostname.replace('-', '--') +
+                         "-openstack-")
+        self.assertEqual(agent.etcd.subnet_watcher.prefix,
+                         datamodel_v1.SUBNET_DIR)
+
+    def test_host_config(self):
+        cfg.CONF.host = "my-special-hostname"
+        agent = CalicoDhcpAgent()
+        self.assertEqual(agent.etcd.prefix,
+                         "/calico/resources/v3/projectcalico.org/" +
+                         "workloadendpoints/openstack/" +
+                         "my--special--hostname" +
+                         "-openstack-")
         self.assertEqual(agent.etcd.subnet_watcher.prefix,
                          datamodel_v1.SUBNET_DIR)
 
